==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/TargetPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Group specific to the update configuration.
 * @property azureQueries List of Azure queries in the software update configuration.
 * @property nonAzureQueries List of non Azure queries in the software update configuration.
 */
public data class TargetPropertiesArgs(
    public val azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null,
    public val nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder()
            .azureQueries(
                azureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .nonAzureQueries(
                nonAzureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TargetPropertiesArgs].
 */
@PulumiTagMarker
public class TargetPropertiesArgsBuilder internal constructor() {
    private var azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null

    private var nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("npnqloqofarktcmv")
    public suspend fun azureQueries(`value`: Output<List<AzureQueryPropertiesArgs>>) {
        this.azureQueries = value
    }

    @JvmName("tqhqsxalgiwwmwik")
    public suspend fun azureQueries(vararg values: Output<AzureQueryPropertiesArgs>) {
        this.azureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("jmgflcppleyvcesq")
    public suspend fun azureQueries(values: List<Output<AzureQueryPropertiesArgs>>) {
        this.azureQueries = Output.all(values)
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("htauqtetwxevmwsi")
    public suspend fun nonAzureQueries(`value`: Output<List<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = value
    }

    @JvmName("ckjnmnfjdxirwbjl")
    public suspend fun nonAzureQueries(vararg values: Output<NonAzureQueryPropertiesArgs>) {
        this.nonAzureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("fbvdlakndbablbor")
    public suspend fun nonAzureQueries(values: List<Output<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = Output.all(values)
    }

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("lqhfhsbnufoivhfh")
    public suspend fun azureQueries(`value`: List<AzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("axjsmgltksdajjle")
    public suspend
    fun azureQueries(argument: List<suspend AzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("qsvupotlwuryvwuv")
    public suspend fun azureQueries(
        vararg
        argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("vaywaikfimvewomb")
    public suspend fun azureQueries(argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AzureQueryPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("bugdukadmbkrfbdv")
    public suspend fun azureQueries(vararg values: AzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("elhtndoagulkjwsf")
    public suspend fun nonAzureQueries(`value`: List<NonAzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("dwifkshfceripupb")
    public suspend
    fun nonAzureQueries(argument: List<suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("cvyrdhuxxqahdlys")
    public suspend fun nonAzureQueries(
        vararg
        argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("oloipqlxqlbvjxtl")
    public suspend
    fun nonAzureQueries(argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("acgrsflyjcslpdrd")
    public suspend fun nonAzureQueries(vararg values: NonAzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    internal fun build(): TargetPropertiesArgs = TargetPropertiesArgs(
        azureQueries = azureQueries,
        nonAzureQueries = nonAzureQueries,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/TargetPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Group specific to the update configuration.
 * @property azureQueries List of Azure queries in the software update configuration.
 * @property nonAzureQueries List of non Azure queries in the software update configuration.
 */
public data class TargetPropertiesArgs(
    public val azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null,
    public val nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.TargetPropertiesArgs.builder()
            .azureQueries(
                azureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .nonAzureQueries(
                nonAzureQueries?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [TargetPropertiesArgs].
 */
@PulumiTagMarker
public class TargetPropertiesArgsBuilder internal constructor() {
    private var azureQueries: Output<List<AzureQueryPropertiesArgs>>? = null

    private var nonAzureQueries: Output<List<NonAzureQueryPropertiesArgs>>? = null

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("ptxjcmacvfalobbw")
    public suspend fun azureQueries(`value`: Output<List<AzureQueryPropertiesArgs>>) {
        this.azureQueries = value
    }

    @JvmName("brusbvsotlpjehhx")
    public suspend fun azureQueries(vararg values: Output<AzureQueryPropertiesArgs>) {
        this.azureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("jtmildvxfdugncky")
    public suspend fun azureQueries(values: List<Output<AzureQueryPropertiesArgs>>) {
        this.azureQueries = Output.all(values)
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("oeyrhunvccdgnpqi")
    public suspend fun nonAzureQueries(`value`: Output<List<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = value
    }

    @JvmName("daahyifawxliwyup")
    public suspend fun nonAzureQueries(vararg values: Output<NonAzureQueryPropertiesArgs>) {
        this.nonAzureQueries = Output.all(values.asList())
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("rhilmtgssluhjiei")
    public suspend fun nonAzureQueries(values: List<Output<NonAzureQueryPropertiesArgs>>) {
        this.nonAzureQueries = Output.all(values)
    }

    /**
     * @param value List of Azure queries in the software update configuration.
     */
    @JvmName("adryjqlcyvmvytoy")
    public suspend fun azureQueries(`value`: List<AzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("ijnhvtrxphbptqfn")
    public suspend
    fun azureQueries(argument: List<suspend AzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("nfkibdferqjnlmlx")
    public suspend fun azureQueries(
        vararg
        argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param argument List of Azure queries in the software update configuration.
     */
    @JvmName("vyadffvouipjmswu")
    public suspend fun azureQueries(argument: suspend AzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AzureQueryPropertiesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.azureQueries = mapped
    }

    /**
     * @param values List of Azure queries in the software update configuration.
     */
    @JvmName("anxbyvgratobcpjh")
    public suspend fun azureQueries(vararg values: AzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azureQueries = mapped
    }

    /**
     * @param value List of non Azure queries in the software update configuration.
     */
    @JvmName("etbojhciintloiru")
    public suspend fun nonAzureQueries(`value`: List<NonAzureQueryPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("hlrtnxrhkqgqwkpw")
    public suspend
    fun nonAzureQueries(argument: List<suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("ytlyltjifjulbxwp")
    public suspend fun nonAzureQueries(
        vararg
        argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param argument List of non Azure queries in the software update configuration.
     */
    @JvmName("fgipsxccexcybymh")
    public suspend
    fun nonAzureQueries(argument: suspend NonAzureQueryPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            NonAzureQueryPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.nonAzureQueries = mapped
    }

    /**
     * @param values List of non Azure queries in the software update configuration.
     */
    @JvmName("qcdnisynnssjpsis")
    public suspend fun nonAzureQueries(vararg values: NonAzureQueryPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.nonAzureQueries = mapped
    }

    internal fun build(): TargetPropertiesArgs = TargetPropertiesArgs(
        azureQueries = azureQueries,
        nonAzureQueries = nonAzureQueries,
    )
}
